#
# spec file for package rbutil
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2018-2025, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rbutil
Version:        1.5.1
Release:        1.1
Summary:        Rockbox Firmware Manager
License:        GPL-2.0-only
Group:          Hardware/Other
URL:            https://www.rockbox.org/wiki/RockboxUtility
#Git-Clone:     https://git.rockbox.org/cgit/rockbox.git
Source:         rockbox-rbutil-%{version}.tar.xz
Patch0:         rbutil-no-themeeditor.patch
Patch1:         rbutil-fix-versionstring.patch
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(Qt6Core)
BuildRequires:  pkgconfig(Qt6Core5Compat)
BuildRequires:  pkgconfig(Qt6Linguist)
BuildRequires:  pkgconfig(Qt6Multimedia)
BuildRequires:  pkgconfig(Qt6Network)
BuildRequires:  pkgconfig(Qt6Svg)
BuildRequires:  pkgconfig(Qt6Test)
BuildRequires:  pkgconfig(Qt6Widgets)
BuildRequires:  pkgconfig(bzip2)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(speex)
BuildRequires:  pkgconfig(zlib)
%if 0%{?sle_version} >= 150500 && 0%{?sle_version} < 160000 && 0%{?is_opensuse}
BuildRequires:  gcc12
BuildRequires:  gcc12-c++
%else
BuildRequires:  gcc
BuildRequires:  gcc-c++
%endif

%description
Firmware manager for Rockbox MP3 players.

%prep
%autosetup -p1 -n rockbox-rbutil-%{version}
rm -Rv utils/rbutilqt/zlib

%build
%if 0%{?sle_version} >= 150500 && 0%{?sle_version} < 160000 && 0%{?is_opensuse}
export CC="gcc-12"
export CXX="g++-12"
%endif
#
cd utils
%cmake \
  -DCMAKE_SKIP_RPATH=ON \
  -DBUILD_SHARED_LIBS=OFF
%cmake_build

%install
install -Dm 0755 utils/build/rbutilqt/RockboxUtility %{buildroot}%{_bindir}/RockboxUtility
install -Dm 0644 utils/rbutilqt/RockboxUtility.desktop %{buildroot}%{_datadir}/applications/RockboxUtility.desktop
install -Dm 0644 docs/logo/rockbox-clef.svg %{buildroot}%{_datadir}/pixmaps/rockbox-clef.svg

%check
cd utils
%ctest --exclude-regex TestHttpGet

%files
%license docs/COPYING
%doc utils/rbutilqt/changelog.txt
%{_bindir}/RockboxUtility
%{_datadir}/applications/RockboxUtility.desktop
%{_datadir}//pixmaps/rockbox-clef.svg

%changelog
* Sun May 18 2025 Martin Hauke <mardnh@gmx.de>
- Update to version 1.5.1
  * Fix bootloader installation for Ipods.
  * Fix bootloader installation for Sandisk players.
  * Improve responsiveness on install / uninstall.
  * Enable Themes installation if themes are selected.
- Update to version 1.5.0
  * Add support for xDuoo X3, X3ii, X20.
  * Add support for AGPTek Rocker.
  * Add support for AIGO Eros Q and various clones (AIGO Eros K,
    AGPTek H3, HIFI Walker H2, Surfans F20)
  * Add support for showing "retired" target status.
  * Update Iriver H100 / H300 series bootloader.
  * Rename Game Files installation to Plugin Data; now installs
    files for further games (Duke3D, Wolfenstein3D, etc.) as well
    as other plugins (MIDI patchset).
  * Support installing daily builds.
  * Move Manual / prerendered voice file installation to main
    dialog.
  * Support installing voice files in other languages than english
  * Improved HiDPI support.
  * Drop support for Qt4, now requires Qt5.
  * Update various external libraries.
  * Server Downloads changed to https.
- Remove patch:
  * 0001-imxtools-sbtools-fix-compilation-with-gcc-10.patch
- Update patch:
  * rbutil-fix-versionstring.patch
- Add patch
  * rbutil-no-themeeditor.patch
- Use tar_scm service to create the tarball
- Run tests
- Drop obsolete update-desktop-files
- Force usage of gcc12 on builds for Leap 15.5 and 15.6
* Fri Feb 23 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Sun Jun 14 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 1.4.1
  * Support for mks5lboot installation (iPod 6G)
  * Fix crash when detecting a supported player in MTP mode.
- Update patch:
  * rbutil-fix-versionstring.patch
- Add patch to fix gcc10 compilation errors (boo#1160244)
  * 0001-imxtools-sbtools-fix-compilation-with-gcc-10.patch
* Sun Jul 29 2018 jengelh@inai.de
- Trim redundancies from description.
* Sun Jun  3 2018 mardnh@gmx.de
- Initial package
